.. _intro-use-cases:

=========
Use cases
=========

**IT-as-a-Service**

 An *IT organization* manages applications and controls the applications
 availability to different OpenStack cloud users in a simple and timesaving
 manner.

 A *cloud end user* can easily find and deploy any available application
 from the catalog.

**Self-service portal**

 An *application developer* and *quality assurance engineer* reduces efforts
 on testing an application for compatibility with other applications,
 databases, platforms, and other components it depends on, by configuring
 compound combinations of applications dynamically and deploying
 environments that satisfy all requirements within minutes.

**Glue layer use case**

 A *cloud end user* is able to link an ever growing number of technologies
 to any application in an OpenStack cloud with a minimum cost due to
 the powerful Murano architecture.

 Currently, Murano applications have been integrated with the following
 technologies: Docker, Legacy apps VMs or bare metal, apps outside of
 OpenStack, and others.

 The following technologies are to become available in the future:
 Cloudify and TOSCA, Apache Brooklyn, and APS.

